HDAWG
=====


.. autoclass:: zhinst.qcodes.HDAWG
    :show-inheritance:
    :members:


AWG Core for HDAWG
------------------

.. autoclass:: zhinst.qcodes.hdawg.AWG
    :show-inheritance:
    :members: